# procs-groovy-jupyter.md
⊕ [BeakerX](http://beakerx.com/)
⊕ [Jupyter kernels · jupyter/jupyter Wiki](https://github.com/jupyter/jupyter/wiki/Jupyter-kernels)
⊕ [twosigma/beakerx: Beaker Extensions for Jupyter Notebook](https://github.com/twosigma/beakerx)
⊕ [error during install, notebook 5.6? · Issue #7708 · twosigma/beakerx](https://github.com/twosigma/beakerx/issues/7708)
     if you do not have conda version 4.4.9 or newer, please update it and try to install the lab again

⊕ [beakerx/doc/groovy at master · twosigma/beakerx](https://github.com/twosigma/beakerx/tree/master/doc/groovy)
⊕ [beakerx/Java.ipynb at master · twosigma/beakerx](https://github.com/twosigma/beakerx/blob/master/doc/java/Java.ipynb)
⊕ [beakerx/Scala.ipynb at master · twosigma/beakerx](https://github.com/twosigma/beakerx/blob/master/doc/scala/Scala.ipynb)

## start
```sh
# conda version 4.4.9 or newer
conda install -c conda-forge jupyter ipywidgets beakerx

beakerx install
beakerx_databrowser install
```
